@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::CopyrightYearFromGit;
 
-our $DATE = '2017-02-10'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2019-10-24'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -12,6 +12,8 @@ with (
     'Dist::Zilla::Role::BeforeBuild',
 );
 
+has min_year => (is => 'rw');
+
 sub before_build {
     require Release::Util::Git;
     my $self = shift;
@@ -20,10 +22,15 @@ sub before_build {
     $self->log_fatal(["%s - %s"], $res->[0], $res->[1]) unless $res->[0] == 200;
 
     my $cur_year = (localtime)[5]+1900;
+
+    my $min_year = $self->min_year;
+    $min_year = $cur_year if defined $min_year && $min_year > $cur_year;
+
     my @years = @{ $res->[2] };
     if (!@years || $years[0] < $cur_year) {
         unshift @years, $cur_year;
     }
+    @years = grep { !defined($min_year) || $_ >= $min_year } @years;
     my $year = join(", ", sort {$b <=> $a} @years);
     $self->log(["Setting copyright_year to %s", $year]);
 
@@ -48,7 +55,7 @@ Dist::Zilla::Plugin::CopyrightYearFromGit - Set copyright year from git
 
 =head1 VERSION
 
-This document describes version 0.003 of Dist::Zilla::Plugin::CopyrightYearFromGit (from Perl distribution Dist-Zilla-Plugin-CopyrightYearFromGit), released on 2017-02-10.
+This document describes version 0.004 of Dist::Zilla::Plugin::CopyrightYearFromGit (from Perl distribution Dist-Zilla-Plugin-CopyrightYearFromGit), released on 2019-10-24.
 
 =head1 SYNOPSIS
 
@@ -63,14 +70,22 @@ This plugin will set copyright year to something like:
  2017, 2015, 2014, 2013
 
 where the years will be retrieved from 1) the date of git tags that resemble
-version string (qr/^(version|ver|v)?\d/); 2) current date; and will be listed in descending
-order in a comma-separated list. This format is commonly used in books, where
-the year of each revision/edition is mentioned, e.g.:
+version string (qr/^(version|ver|v)?\d/); 2) current date; and will be listed in
+descending order in a comma-separated list. This format is commonly used in
+books, where the year of each revision/edition is mentioned, e.g.:
 
  Copyright (c) 2013, 2010, 2008, 2006 by Pearson Education, Inc.
 
 =for Pod::Coverage .+
 
+=head1 CONFIGURATION
+
+=head2 min_year
+
+Instruct the plugin to not include years below this year. Note that the current
+year will always be used, even though C<min_year> is (incorrectly) set to a
+value larger than the current year.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-CopyrightYearFromGit>.
@@ -95,7 +110,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
